=======================
BioMed Sheets Changelog
=======================

----
v0.3
----

- Adding possibility for generic TSV sample sheets.
- Many updates to make documentation more clear.
- Various updates, fixing Codacy issues.
- Adding routines for writing out PED file from germline sample sheets.

----
v0.2
----

- Auto-deployment to pypi
- Fixing shortcuts to father/mother during cohort loading
- Cleanup code (according to Flake 8)
- Adding more tests, replacing examples by TSV files
- Removing protein pools
- Adding Sphinx-based ocumentation
- Restructuring requirements txt files
- Configurable entity name generation.
  This allows to use secondary id only for naming, e.g.
- Fixing ``requirements*.txt`` files for always using SSH
- Fixing sample naming for germline sample sheets
- Adding versioneer integration

------
v0.1.1
------

- First actual release, versioning done using versioneer
- Everything is new!
